%% DIVERSITY.M - Diversity of classifier ensemble


% BASECL     - Cell array of L base classifiers results 
% type)

% DIVTYPES - Cell array of D diversity measures to compute. See Kuncheva, Ludmila I., and Christopher J. Whitaker. "Measures of diversity in classifier ensembles and their relationship with the ensemble accuracy." Machine learning 51.2 (2003): 181-207.


% Output = L x L x D matrix of classifier distances

function d = diversityMatrix(baseCl, divTypes)


if nargin<2
    divTypes={'q'};
end

x = prdataset(baseCl{1}.data, baseCl{1}.nlab)
x = setfeatlab(x, baseCl{1}.featlab);

%Ground truth labels (this is needed for some diversity measures)
truth=renumlab(x.labels);
    
L=length(baseCl);
N=length(truth);


        for i=1:L
            
            base1=prdataset(baseCl{i}.data, baseCl{i}.nlab);
            base1 = setfeatlab(base1, baseCl{i}.featlab);
            labels1=renumlab(base1*labeld); %Which labels classifier i assigns to the samples
            dif1=abs(truth-labels1);                   

            for j=1:L
               if j>i         %Assume the measures are symmetric so only compute (i,j) pairs and copy to (j,i)

                 %  try
                   base2=prdataset(baseCl{j}.data, baseCl{j}.nlab);
                   base2 = setfeatlab(base2, baseCl{j}.featlab);
                %   catch
                %       keyboard
                %   end
                   labels2=renumlab(base2*labeld); %Which labels classifier j assigns to the samples
                   dif2=abs(truth-labels2);

                   tot=dif1+dif2;

                   n11=length(find(tot==0));   %Both right
                   n00=length(find(tot==2));   %Both wrong
                   n01 = length(find(dif1 > dif2)); %First is wrong
                   n10 = length(find(dif1 < dif2)); %Second is wrong
                   
       
                   for dt=1:length(divTypes)
                       switch divTypes{dt}
                           case {'dis', 'disagree'}  %Disagreement
                            divScore = (n01+n10)/N;

                           case {'q', 'Q'}                 %Q statistics

                               qsum= n11*n00 + n01*n10;
                               if(qsum == 0)
                                   divScore = 0;
                               else
                                   divScore = (n11*n00 - n01*n10)/qsum;
                               end

                           case {'k', 'kappa'}
                               
                               %Normalized versions first
                               s11 = n11/N; s10 = n10/N; s01 = n01/N; s00 = n00/N;
                               
                               divScore = ( 2*(s11*s00 - s01*s10) ) / ( (s11 + s00)*(s01 + s10) + (s11 + s01)*(s00+s10)   );
                               
                       

                           case {'df', 'doublefault'}        %Double fault

                            divScore=n00/N;    
                       end
                       d(i,j,dt) = divScore;
                       d(j,i,dt) = divScore;
                   end
               end
            end
        end

       
        
end


