%PRIMSVC

function W = primsvc(x,C)

if nargin < 2
    C = 1;
end

if nargin < 1 | isempty(x)
    W = prmapping(mfilename,{C});
    W = setname(W,'Primal SVM');
    
else % training
    islabtype(x,'crisp');
    isvaldfile(x,1,2); % at least 1 object per class, 2 classes
    x = testdatasize(x,'objects');
    [m,k,c] = getsize(x);
    nlab = getnlab(x);
    prior=getprior(x);
    
    
    if c > 2   % two-class classifier
        W = mclassc(x,prmapping(mfilename,{C}));
        
        
    else   % multi-class classifier:
        v = scalem(x,'variance');
        x = x*v;
        
        %Initialize labels (Set class 1 to 1 and class 2 to -1)
        y = nlab;
        y = -((y-1).*2-1);
        
        
        X = [x, ones(m,1)];

        initweights = zeros(1,k+1);
        
        options = [];
        options.display = 'none';
        [weights] = minFunc(@hingeLossL2,initweights',options,X,y,C);
        
     
        w0 = weights(k+1);
        R  = weights(1:k);
        
        W  = v*affine([R -R],[w0 -w0],x,getlablist(x));
        W  = setout_conv(W,1);
    end
  
    W = setname(W,'Primal SVM');
end

function [loss g] = hingeLossL2(weights,X,y,C)

margin = max(0, 1 - y .* (X*weights));
loss = (0.5 * sum(weights.^2)) + C*sum(margin.^2);
loss = sum(loss);
g = weights - 2 * C * (X' * (margin .* y));
g = g(:);
return
